Struct googapis::google::cloud::tasks::v2::Task[][src]

pub struct Task {
    pub name: String,
    pub schedule_time: Option<Timestamp>,
    pub create_time: Option<Timestamp>,
    pub dispatch_deadline: Option<Duration>,
    pub dispatch_count: i32,
    pub response_count: i32,
    pub first_attempt: Option<Attempt>,
    pub last_attempt: Option<Attempt>,
    pub view: i32,
    pub message_type: Option<MessageType>,
}
A unit of scheduled work.

Fields

name: String

Optionally caller-specified in [CreateTask][google.cloud.tasks.v2.CloudTasks.CreateTask].

The task name.

The task name must have the following format: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks/TASK_ID

schedule_time: Option<Timestamp>

The time when the task is scheduled to be attempted or retried.

schedule_time will be truncated to the nearest microsecond.

create_time: Option<Timestamp>

Output only. The time that the task was created.

create_time will be truncated to the nearest second.

dispatch_deadline: Option<Duration>

The deadline for requests sent to the worker. If the worker does not respond by this deadline then the request is cancelled and the attempt is marked as a DEADLINE_EXCEEDED failure. Cloud Tasks will retry the task according to the [RetryConfig][google.cloud.tasks.v2.RetryConfig].

Note that when the request is cancelled, Cloud Tasks will stop listing for the response, but whether the worker stops processing depends on the worker. For example, if the worker is stuck, it may not react to cancelled requests.

The default and maximum values depend on the type of request:

dispatch_deadline will be truncated to the nearest millisecond. The deadline is an approximate deadline.

dispatch_count: i32

Output only. The number of attempts dispatched.

This count includes attempts which have been dispatched but haven’t received a response.

response_count: i32

Output only. The number of attempts which have received a response.

first_attempt: Option<Attempt>

Output only. The status of the task’s first attempt.

Only [dispatch_time][google.cloud.tasks.v2.Attempt.dispatch_time] will be set. The other [Attempt][google.cloud.tasks.v2.Attempt] information is not retained by Cloud Tasks.

last_attempt: Option<Attempt>

Output only. The status of the task’s last attempt.

view: i32

Output only. The view specifies which subset of the [Task][google.cloud.tasks.v2.Task] has been returned.

message_type: Option<MessageType>

Required. The message to send to the worker.

Implementations

Returns the enum value of view, or the default if the field is set to an invalid enum value.

Sets view to the provided enum value.